@@ -25,45 +25,70 @@ class Database(syst3m.objects.Traceback):
 			os.system(f"sudo mkdir {self.path}")
 			Files.chmod(path=self.path, permission=700, sudo=True)
 			Files.chown(path=self.path, owner=syst3m.defaults.vars.user, group=syst3m.defaults.vars.group, sudo=True)
-		self.cache = None
 		if firestore == None:
 			self.mode = "cache"
-			self.cache = syst3m.cache.Cache(path=self.path)
 
 		#
 
 	# functions.
-	def load(self, path=None, format="str"):
+	def load(self, path=None):
 		if path == None: return r3sponse.error(self.__traceback__(function="load")+" Define parameter: [path].")
 		if self.mode == "firestore":
 			return self.firestore.load(path)
 		elif self.mode == "cache":
+			path = gfp.clean(f"{self.path}/{path}")
 			try:
-				data = self.cache.get(group=path, format=format)
+				data = Files.load(path=path, format="json")
 			except Exception as e: return r3sponse.error(str(e))
 			return r3sponse.success(f"Successfully loaded [{path}].", {
 				"data":data,
 			})
 		else: raise exceptions.InvalidUsage(self.__traceback__(function="load")+f" Unknown mode [{self.mode}].")
-	def save(self, path=None, data=None, format="str"):
+	def save(self, path=None, data=None, overwrite=False):
 		if path == None: return r3sponse.error(self.__traceback__(function="save")+" Define parameter: [path].")
 		if data == None: return r3sponse.error(self.__traceback__(function="save")+" Define parameter: [data].")
 		if self.mode == "firestore":
 			return self.firestore.save(path, data)
 		elif self.mode == "cache":
+			path = gfp.clean(f"{self.path}/{path}")
 			try:
-				self.cache.set(group=path, data=data, format=format)
+				if not Files.exists(path=gfp.base(path)): Files.create(path=gfp.base(path), directory=True)
+			except ValueError: a=1
+			if not overwrite:
+				def insert(old, new):
+					for key,value in new.items():
+						if isinstance(value, (dict, Dictionary)):
+							if key in old:
+								old[key] = insert(old[key], value)
+							else:
+								old[key] = value
+						elif isinstance(value, (list, Array)):
+							if key in old:
+								for i in value:
+									if i not in old[key]: old[key].append(i)
+							else:
+								old[key] = value
+						else:
+							old[key] = value
+					return old
+				try: old_data = Files.load(path=path, format="json")
+				except: old_data = {}
+				data = insert(old_data, data)
+			try:
+				Files.save(path=path, data=data, format="json")
 			except Exception as e: return r3sponse.error(str(e))
 			return r3sponse.success(f"Successfully saved [{path}].")
 		else: raise exceptions.InvalidUsage(self.__traceback__(function="save")+f" Unknown mode [{self.mode}].")
-	def delete(self, path=None, data=None, format="str"):
+	def delete(self, path=None, data=None):
 		if path == None: return r3sponse.error(self.__traceback__(function="delete")+" Define parameter: [path].")
 		if self.mode == "firestore":
 			return self.firestore.delete(path)
 		elif self.mode == "cache":
+			path = gfp.clean(f"{self.path}/{path}")
 			try:
-				self.cache.delete(group=path)
+				Files.delete(path=path)
 			except Exception as e: return r3sponse.error(str(e))
+			if Files.exists(path): return r3sponse.error(f"Failed to delete [{path}].")
 			return r3sponse.success(f"Successfully deleted [{path}].")
 		else: raise exceptions.InvalidUsage(self.__traceback__(function="delete")+f" Unknown mode [{self.mode}].")
 
